@@ -509,7 +509,7 @@ static int qGetSqliteTimeout(QString opts)
     enum { DefaultTimeout = 5000 };
 
     opts.remove(QLatin1Char(' '));
-    foreach(const QString &option, opts.split(QLatin1Char(';'))) {
+    Q_FOREACH(const QString &option, opts.split(QLatin1Char(';'))) {
         if (option.startsWith(QLatin1String("QSQLITE_BUSY_TIMEOUT="))) {
             bool ok;
             int nt = option.mid(21).toInt(&ok);
@@ -523,7 +523,7 @@ static int qGetSqliteTimeout(QString opts)
 static int qGetSqliteOpenMode(QString opts)
 {
     opts.remove(QLatin1Char(' '));
-    foreach(const QString &option, opts.split(QLatin1Char(';'))) {
+    Q_FOREACH(const QString &option, opts.split(QLatin1Char(';'))) {
         if (option == QLatin1String("QSQLITE_OPEN_READONLY"))
                 return SQLITE_OPEN_READONLY;
     }
