@@ -34,14 +34,14 @@ class BridgeServerBase : public QObject
     virtual void slotNewConnection() = 0;
 
   protected:
-    QTcpServer* m_server;
+    QTcpServer *m_server;
 };
 
 template <typename ConnectionType>
 class BridgeServer : public BridgeServerBase
 {
   public:
-    explicit BridgeServer( quint16 port, QObject* parent = 0 )
+    explicit BridgeServer( quint16 port, QObject *parent = 0 )
       : BridgeServerBase( port, parent )
     {
     }
@@ -49,8 +49,9 @@ class BridgeServer : public BridgeServerBase
   protected:
     void slotNewConnection()
     {
-      while( m_server->hasPendingConnections() )
+      while ( m_server->hasPendingConnections() ) {
         new ConnectionType( m_server->nextPendingConnection(), this );
+      }
     }
 };
 
