@@ -40,8 +40,9 @@ static AgentManager *sAgentManager = 0;
 
 void crashHandler( int )
 {
-  if ( sAgentManager )
+  if ( sAgentManager ) {
     sAgentManager->cleanup();
+  }
 
   exit( 255 );
 }
@@ -49,23 +50,25 @@ void crashHandler( int )
 int main( int argc, char **argv )
 {
   AkCoreApplication app( argc, argv );
-  app.setDescription( QLatin1String("Akonadi Control Process\nDo not run this manually, use 'akonadictl' instead to start/stop Akonadi.") );
+  app.setDescription( QLatin1String( "Akonadi Control Process\nDo not run this manually, use 'akonadictl' instead to start/stop Akonadi." ) );
   app.parseCommandLine();
 
   // try to acquire the lock first, that means there is no second instance trying to start up at the same time
   // registering the real service name happens in AgentManager::continueStartup(), when everything is in fact up and running
-  if ( !QDBusConnection::sessionBus().registerService( AkDBus::serviceName(AkDBus::ControlLock) ) ) {
+  if ( !QDBusConnection::sessionBus().registerService( AkDBus::serviceName( AkDBus::ControlLock ) ) ) {
     // We couldn't register. Most likely, it's already running.
     const QString lastError = QDBusConnection::sessionBus().lastError().message();
-    if (lastError.isEmpty())
-      akFatal() << "Unable to register service as" << AkDBus::serviceName(AkDBus::ControlLock) << "Maybe it's already running?";
-    else
-      akFatal() << "Unable to register service as" << AkDBus::serviceName(AkDBus::ControlLock) << "Error was:" << lastError;
+    if ( lastError.isEmpty() ) {
+      akFatal() << "Unable to register service as" << AkDBus::serviceName( AkDBus::ControlLock ) << "Maybe it's already running?";
+    } else {
+      akFatal() << "Unable to register service as" << AkDBus::serviceName( AkDBus::ControlLock ) << "Error was:" << lastError;
+    }
   }
 
   // older Akonadi server versions don't use the lock service yet, so check if one is already running before we try to start another one
-  if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName(AkDBus::Control) ) )
+  if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName( AkDBus::Control ) ) ) {
     akFatal() << "Another Akonadi control process is already running.";
+  }
 
   new ControlManager;
 
