@@ -19,10 +19,13 @@
 
 #include "clientcapabilities.h"
 
+using namespace Akonadi::Server;
+
 ClientCapabilities::ClientCapabilities()
   : m_notificationMessageVersion( 0 )
   , m_noPayloadPath( false )
-
+  , m_serverSideSearch( false )
+  , m_akAppendStreaming( false )
 {
 }
 
@@ -53,3 +56,23 @@ void ClientCapabilities::setNoPayloadPath( bool noPayloadPath )
 {
   m_noPayloadPath = noPayloadPath;
 }
+
+bool ClientCapabilities::serverSideSearch() const
+{
+  return m_serverSideSearch;
+}
+
+void ClientCapabilities::setServerSideSearch( bool serverSideSearch )
+{
+  m_serverSideSearch = serverSideSearch;
+}
+
+bool ClientCapabilities::akAppendStreaming() const
+{
+  return m_akAppendStreaming;
+}
+
+void ClientCapabilities::setAkAppendStreaming(bool akAppendStreaming)
+{
+  m_akAppendStreaming = akAppendStreaming;
+}
