@@ -19,8 +19,12 @@
 
 #include "capability.h"
 
-#ifndef CLIENTCAPABILITIES_H
-#define CLIENTCAPABILITIES_H
+#ifndef AKONADI_CLIENTCAPABILITIES_H
+#define AKONADI_CLIENTCAPABILITIES_H
+
+
+namespace Akonadi {
+namespace Server {
 
 /** Describes the capabilities of a specific session.
     Filled by the CAPABILITY command.
@@ -41,9 +45,20 @@ public:
   bool noPayloadPath() const;
   void setNoPayloadPath( bool noPayloadPath );
 
+  void setServerSideSearch( bool serverSideSearch );
+  bool serverSideSearch() const;
+
+  bool akAppendStreaming() const;
+  void setAkAppendStreaming( bool akAppendStreaming );
+
 private:
   int m_notificationMessageVersion;
   int m_noPayloadPath : 1;
+  int m_serverSideSearch : 1;
+  int m_akAppendStreaming : 1;
 };
 
+} // namespace Server
+} // namespace Akonadi
+
 #endif // CLIENTCAPABILITIES_H
