@@ -20,10 +20,10 @@
 #include "debuginterface.h"
 #include "debuginterfaceadaptor.h"
 #include "tracer.h"
-using Akonadi::Tracer;
-
 #include <QtDBus>
 
+using namespace Akonadi::Server;
+
 DebugInterface::DebugInterface( QObject *parent )
   : QObject( parent )
 {
