@@ -22,13 +22,14 @@
 #include "response.h"
 #include "imapstreamparser.h"
 #include "clientcapabilities.h"
-#include "akonadiconnection.h"
+#include "connection.h"
 
 #include <libs/protocol_p.h>
 
 #include <QtCore/QDebug>
 
 using namespace Akonadi;
+using namespace Server;
 
 Capability::Capability(): Handler()
 {
@@ -52,6 +53,10 @@ bool Capability::parseStream()
       capabilities.setNotificationMessageVersion( m_streamParser->readNumber() );
     } else if ( capability == AKONADI_PARAM_CAPABILITY_NOPAYLOADPATH ) {
       capabilities.setNoPayloadPath( true );
+    } else if ( capability == AKONADI_PARAM_CAPABILITY_SERVERSEARCH ) {
+      capabilities.setServerSideSearch( true );
+    } else if ( capability == AKONADI_PARAM_CAPABILITY_AKAPPENDSTREAMING ) {
+      capabilities.setAkAppendStreaming( true );
     } else {
       qDebug() << Q_FUNC_INFO << "Unknown client capability:" << capability;
     }
