@@ -21,6 +21,7 @@
 
 #include "connection.h"
 #include "handlerhelper.h"
+#include "cachecleaner.h"
 #include "storage/datastore.h"
 #include "storage/transaction.h"
 #include "storage/itemretriever.h"
@@ -98,6 +99,8 @@ bool ColCopy::parseStream()
     return failureResponse( "No valid target specified" );
   }
 
+  CacheCleanerInhibitor inhibitor;
+
   // retrieve all not yet cached items of the source
   ItemRetriever retriever( connection() );
   retriever.setCollection( source, true );
