@@ -26,6 +26,7 @@
 #include <storage/transaction.h>
 #include <storage/collectionqueryhelper.h>
 #include <storage/selectquerybuilder.h>
+#include <cachecleaner.h>
 #include <akdebug.h>
 
 using namespace Akonadi;
@@ -61,6 +62,8 @@ bool ColMove::parseStream()
     return successResponse( "COLMOVE complete - nothing to do" );
   }
 
+  CacheCleanerInhibitor inhibitor;
+
   // retrieve all not yet cached items of the source
   ItemRetriever retriever( connection() );
   retriever.setCollection( source, true );
