@@ -21,6 +21,7 @@
 
 #include "connection.h"
 #include "handlerhelper.h"
+#include "cachecleaner.h"
 
 #include "storage/datastore.h"
 #include "storage/itemqueryhelper.h"
@@ -74,6 +75,8 @@ bool Copy::parseStream()
     return failureResponse( "No items specified" );
   }
 
+  CacheCleanerInhibitor inhibitor;
+
   ItemRetriever retriever( connection() );
   retriever.setItemSet( set );
   retriever.setRetrieveFullPayload( true );
