@@ -23,6 +23,7 @@
 #include "connection.h"
 #include "fetchhelper.h"
 #include "response.h"
+#include "cachecleaner.h"
 
 #include <libs/protocol_p.h>
 
@@ -39,6 +40,8 @@ bool Fetch::parseStream()
   // sequence set
   mScope.parseScope( m_streamParser );
 
+  CacheCleanerInhibitor inhibitor;
+
   FetchHelper fetchHelper( connection(), mScope, FetchScope( m_streamParser ) );
   connect( &fetchHelper, SIGNAL(responseAvailable(Akonadi::Server::Response)),
            this, SIGNAL(responseAvailable(Akonadi::Server::Response)) );
