@@ -284,6 +284,7 @@ bool FetchHelper::fetchItems( const QByteArray &responseIdentifier )
     retriever.setScope( mScope );
     retriever.setRetrieveParts( mFetchScope.requestedPayloads() );
     retriever.setRetrieveFullPayload( mFetchScope.fullPayload() );
+    retriever.setChangedSince( mFetchScope.changedSince() );
     if ( !retriever.exec() && !mFetchScope.ignoreErrors() ) { // There we go, retrieve the missing parts from the resource.
       if ( mConnection->resourceContext().isValid() ) {
         throw HandlerException( QString::fromLatin1( "Unable to fetch item from backend (collection %1, resource %2) : %3" )
@@ -303,6 +304,9 @@ bool FetchHelper::fetchItems( const QByteArray &responseIdentifier )
   // error if query did not find any item and scope is not listing items but
   // a request for a specific item
   if ( !itemQuery.isValid() ) {
+    if ( mFetchScope.ignoreErrors() ) {
+      return true;
+    }
     switch ( mScope.scope() ) {
     case Scope::Uid: // fall through
     case Scope::Rid: // fall through
