@@ -25,7 +25,7 @@
 #include "storage/entity.h"
 #include "storage/selectquerybuilder.h"
 
-#include "akonadiconnection.h"
+#include "connection.h"
 #include "response.h"
 #include "handlerhelper.h"
 #include "imapstreamparser.h"
@@ -33,7 +33,7 @@
 #include <libs/protocol_p.h>
 #include <storage/collectionqueryhelper.h>
 
-using namespace Akonadi;
+using namespace Akonadi::Server;
 
 template <typename T>
 static bool intersect( const QVector<typename T::Id> &l1, const QVector<T> &l2 )
@@ -71,7 +71,7 @@ QStack<Collection> List::ancestorsForCollection( const Collection &col )
   return ancestors;
 }
 
-bool List::listCollection( const Collection &root, int depth, const QStack<Collection> &ancestors  )
+bool List::listCollection( const Collection &root, int depth, const QStack<Collection> &ancestors )
 {
   // recursive listing of child collections
   bool childrenFound = false;
