@@ -19,7 +19,7 @@
 
 #include "remove.h"
 
-#include <akonadiconnection.h>
+#include <connection.h>
 #include <entities.h>
 #include <imapstreamparser.h>
 #include <storage/datastore.h>
@@ -28,7 +28,8 @@
 #include <storage/transaction.h>
 #include <libs/imapset_p.h>
 
-namespace Akonadi {
+using namespace Akonadi;
+using namespace Akonadi::Server;
 
 Remove::Remove( Scope::SelectionScope scope )
   : mScope( scope )
@@ -62,5 +63,3 @@ bool Remove::parseStream()
 
   return successResponse( "REMOVE complete" );
 }
-
-}
