@@ -21,7 +21,7 @@
 #include <QtCore/QDebug>
 
 #include "akonadi.h"
-#include "akonadiconnection.h"
+#include "connection.h"
 #include "storage/datastore.h"
 #include "storage/entity.h"
 #include "handlerhelper.h"
@@ -32,7 +32,7 @@
 
 #include <libs/protocol_p.h>
 
-using namespace Akonadi;
+using namespace Akonadi::Server;
 
 Select::Select( Scope::SelectionScope scope )
   : Handler()
