@@ -22,6 +22,7 @@
 #include "storage/countquerybuilder.h"
 #include "storage/datastore.h"
 #include "storage/selectquerybuilder.h"
+#include "storage/queryhelper.h"
 #include "libs/imapparser_p.h"
 #include "libs/protocol_p.h"
 #include "handler.h"
@@ -29,6 +30,7 @@
 #include <QtSql/QSqlError>
 
 using namespace Akonadi;
+using namespace Akonadi::Server;
 
 Collection HandlerHelper::collectionFromIdOrName( const QByteArray &id )
 {
@@ -75,7 +77,7 @@ QString HandlerHelper::pathForCollection( const Collection &col )
   return parts.join( QLatin1String( "/" ) );
 }
 
-bool HandlerHelper::itemStatistics( const Akonadi::Collection &col, qint64 &count, qint64 &size )
+bool HandlerHelper::itemStatistics( const Collection &col, qint64 &count, qint64 &size )
 {
   QueryBuilder qb( PimItem::tableName() );
   qb.addAggregation( PimItem::idColumn(), QLatin1String( "count" ) );
@@ -101,7 +103,7 @@ bool HandlerHelper::itemStatistics( const Akonadi::Collection &col, qint64 &coun
   return true;
 }
 
-int HandlerHelper::itemWithFlagsCount( const Akonadi::Collection &col, const QStringList &flags )
+int HandlerHelper::itemWithFlagsCount( const Collection &col, const QStringList &flags )
 {
   CountQueryBuilder qb( PimItem::tableName(), PimItem::idFullColumnName(), CountQueryBuilder::Distinct );
   qb.addJoin( QueryBuilder::InnerJoin, PimItemFlagRelation::tableName(),
@@ -115,7 +117,7 @@ int HandlerHelper::itemWithFlagsCount( const Akonadi::Collection &col, const QSt
   }
   Query::Condition cond( Query::Or );
   // We use the below instead of an inner join in the query above because postgres seems
-  // to struggle to optimize the two inner joins, despite having indeces that should
+  // to struggle to optimize the two inner joins, despite having indices that should
   // facilitate that. This exploits the fact that the Flag::retrieveByName is fast because
   // it hits an in-memory cache.
   Q_FOREACH ( const QString &flag, flags ) {
@@ -145,7 +147,7 @@ int HandlerHelper::parseCachePolicy( const QByteArray &data, Collection &col, in
   bool somethingElseChanged = false;
 
   QList<QByteArray> params;
-  int end = Akonadi::ImapParser::parseParenthesizedList( data, params, start );
+  int end = ImapParser::parseParenthesizedList( data, params, start );
   for ( int i = 0; i < params.count() - 1; i += 2 ) {
     const QByteArray key = params[i];
     const QByteArray value = params[i + 1];
@@ -169,7 +171,7 @@ int HandlerHelper::parseCachePolicy( const QByteArray &data, Collection &col, in
     } else if ( key == AKONADI_PARAM_LOCALPARTS ) {
       QList<QByteArray> tmp;
       QStringList partsList;
-      Akonadi::ImapParser::parseParenthesizedList( value, tmp );
+      ImapParser::parseParenthesizedList( value, tmp );
       Q_FOREACH ( const QByteArray &ba, tmp ) {
         partsList << QString::fromLatin1( ba );
       }
@@ -227,13 +229,14 @@ QByteArray HandlerHelper::collectionToByteArray( const Collection &col, bool hid
     }
   }
 
-  if ( !col.queryLanguage().isEmpty() ) {
+  if ( !col.queryString().isEmpty() ) {
     b += AKONADI_PARAM_PERSISTENTSEARCH " ";
     QList<QByteArray> args;
-    args.append( AKONADI_PARAM_PERSISTENTSEARCH_QUERYLANG );
-    args.append( col.queryLanguage().toLatin1() );
+    args.append( col.queryAttributes().toLatin1() );
     args.append( AKONADI_PARAM_PERSISTENTSEARCH_QUERYSTRING );
     args.append( ImapParser::quote( col.queryString().toUtf8() ) );
+    args.append( AKONADI_PARAM_PERSISTENTSEARCH_QUERYCOLLECTIONS );
+    args.append( "(" + col.queryCollections().toLatin1() + ")" );
     b += ImapParser::quote( "(" + ImapParser::join( args, " " ) + ")" );
     b += ' ';
   }
@@ -246,6 +249,10 @@ QByteArray HandlerHelper::collectionToByteArray( const Collection &col, bool hid
   const CollectionAttribute::List attrs = col.attributes();
   for ( int i = 0; i < attrs.size(); ++i ) {
     const CollectionAttribute &attr = attrs[i];
+    //Workaround to skip invalid "PARENT " attributes that were accidentaly created after 6e5bbf6
+    if ( attr.type() == "PARENT" ) {
+      continue;
+    }
     b += attr.type() + ' ' + ImapParser::quote( attr.value() );
     if ( i != attrs.size() - 1 ) {
       b += ' ';
@@ -297,7 +304,7 @@ int HandlerHelper::parseDepth( const QByteArray &depth )
   return result;
 }
 
-Akonadi::Flag::List Akonadi::HandlerHelper::resolveFlags( const QList< QByteArray > &flagNames )
+Flag::List HandlerHelper::resolveFlags( const QList< QByteArray > &flagNames )
 {
   Flag::List flagList;
   Q_FOREACH ( const QByteArray &flagName, flagNames ) {
@@ -312,3 +319,17 @@ Akonadi::Flag::List Akonadi::HandlerHelper::resolveFlags( const QList< QByteArra
   }
   return flagList;
 }
+
+Tag::List HandlerHelper::resolveTags( const ImapSet &tags )
+{
+  SelectQueryBuilder<Tag> qb;
+  QueryHelper::setToQuery( tags, Tag::idFullColumnName(), qb );
+  if ( !qb.exec() ) {
+    throw HandlerException( "Unable to resolve tags" );
+  }
+  const Tag::List result = qb.result();
+  if ( result.isEmpty() ) {
+    throw HandlerException( "No tags found" );
+  }
+  return result;
+}
