@@ -214,7 +214,7 @@ void SearchTaskManager::searchLoop()
 
   Q_FOREVER {
     akDebug() << "Search loop is waiting, will wake again in" << timeout << "ms";
-    mWait.wait( &mLock, timeout ); // wait for a minute
+    mWait.wait( &mLock, timeout );
 
     if ( mShouldStop ) {
       Q_FOREACH (SearchTask *task, mTasklist ) {
