@@ -19,7 +19,7 @@
 
 #include "collectionqueryhelper.h"
 
-#include "akonadiconnection.h"
+#include "connection.h"
 #include "entities.h"
 #include "storage/querybuilder.h"
 #include "storage/selectquerybuilder.h"
@@ -28,9 +28,9 @@
 #include "handler.h"
 #include "queryhelper.h"
 
-using namespace Akonadi;
+using namespace Akonadi::Server;
 
-void CollectionQueryHelper::remoteIdToQuery( const QStringList &rids, AkonadiConnection *connection, QueryBuilder &qb )
+void CollectionQueryHelper::remoteIdToQuery( const QStringList &rids, Connection *connection, QueryBuilder &qb )
 {
   if ( rids.size() == 1 ) {
     qb.addValueCondition( Collection::remoteIdFullColumnName(), Query::Equals, rids.first() );
@@ -43,7 +43,7 @@ void CollectionQueryHelper::remoteIdToQuery( const QStringList &rids, AkonadiCon
   }
 }
 
-void CollectionQueryHelper::scopeToQuery( const Scope &scope, AkonadiConnection *connection, QueryBuilder &qb )
+void CollectionQueryHelper::scopeToQuery( const Scope &scope, Connection *connection, QueryBuilder &qb )
 {
   if ( scope.scope() == Scope::None || scope.scope() == Scope::Uid ) {
     QueryHelper::setToQuery( scope.uidSet(), Collection::idFullColumnName(), qb );
@@ -135,7 +135,7 @@ Collection CollectionQueryHelper::resolveHierarchicalRID( const QStringList &rid
   return result;
 }
 
-Collection Akonadi::CollectionQueryHelper::singleCollectionFromScope( const Akonadi::Scope &scope, AkonadiConnection *connection )
+Collection CollectionQueryHelper::singleCollectionFromScope( const Scope &scope, Connection *connection )
 {
   // root
   if ( ( scope.scope() == Scope::Uid || scope.scope() == Scope::None ) && scope.uidSet().intervals().count() == 1 ) {
