@@ -29,6 +29,7 @@
 #include <QtSql/QSqlQuery>
 
 using namespace Akonadi;
+using namespace Akonadi::Server;
 
 static QString dataDir()
 {
@@ -180,8 +181,6 @@ void DbConfigSqlite::setup()
   const int sqliteVersionMajor = list[0].toInt();
   const int sqliteVersionMinor = list[1].toInt();
 
-#ifndef Q_OS_WINCE
-
   // set synchronous mode to NORMAL; see http://www.sqlite.org/pragma.html#pragma_synchronous
   if ( !query.exec( QLatin1String( "PRAGMA synchronous = 1" ) ) ) {
     akDebug() << "Could not set sqlite synchronous mode to NORMAL";
@@ -220,8 +219,6 @@ void DbConfigSqlite::setup()
   const QString journalMode = query.value( 0 ).toString();
   akDebug() << "sqlite journal mode is " << journalMode;
 
-#endif // Q_OS_WINCE
-
   db.close();
 
   QSqlDatabase::removeDatabase( connectionName );
