@@ -19,6 +19,8 @@
 
 #include "dbtype.h"
 
+using namespace Akonadi::Server;
+
 DbType::Type DbType::type( const QSqlDatabase &db )
 {
   return typeForDriverName( db.driverName() );
@@ -35,8 +37,5 @@ DbType::Type DbType::typeForDriverName( const QString &driverName )
   if ( driverName.startsWith( QLatin1String( "QSQLITE" ) ) ) {
     return Sqlite;
   }
-  if ( driverName.startsWith( QLatin1String( "QODBC" ) ) ) {
-    return Virtuoso;
-  }
   return Unknown;
 }
