@@ -115,6 +115,11 @@ Scope ItemRetriever::scope() const
   return mScope;
 }
 
+void ItemRetriever::setChangedSince( const QDateTime &changedSince )
+{
+  mChangedSince = changedSince;
+}
+
 QStringList ItemRetriever::retrieveParts() const
 {
   return mParts;
@@ -171,6 +176,11 @@ QSqlQuery ItemRetriever::buildQuery() const
                           QString::fromLatin1( mConnection->sessionId() ) );
   }
 
+  if ( mChangedSince.isValid() ) {
+    qb.addValueCondition( PimItem::datetimeFullColumnName(), Query::GreaterOrEqual,
+                          mChangedSince.toUTC() );
+  }
+
   qb.addSortColumn( PimItem::idFullColumnName(), Query::Ascending );
 
   if ( !qb.exec() ) {
