@@ -26,9 +26,12 @@
 
 class QString;
 class QVariant;
+class QFile;
 
-namespace Akonadi
-{
+namespace Akonadi {
+namespace Server {
+
+class ImapStreamParser;
 
 AKONADI_EXCEPTION_MAKE_INSTANCE( PartHelperException );
 
@@ -67,6 +70,15 @@ namespace PartHelper
    */
   void removeFile( const QString &fileName );
 
+  /**
+   * Reads data from @p streamParser as they arrive from client and writes them
+   * to @p partFile. It will close the file when all data are read.
+   *
+   * @param partFile File to write into. The file must be closed, or opened in write mode
+   * @throws PartHelperException when an error occurs (write fails, data truncated, etc)
+   */
+  bool streamToFile( ImapStreamParser *streamParser, QFile &partFile, QIODevice::OpenMode = QIODevice::WriteOnly );
+
   /** Returns the payload data. */
   QByteArray translateData( const QByteArray &data, bool isExternal );
   /** Convenience overload of the above. */
@@ -77,7 +89,7 @@ namespace PartHelper
   bool truncate( Part &part );
 
   /** Verifies and if necessary fixes the external reference of this part. */
-  bool verify( Akonadi::Part &part );
+  bool verify( Part &part );
 
 // private: for unit testing only
   /**
@@ -95,8 +107,25 @@ namespace PartHelper
    * Read filename from @p data and returns absolute filepath
    */
   QString resolveAbsolutePath( const QByteArray &data );
-}
 
-}
+  /**
+   * Reads parts data from @p streamParser and stores them directly into Akonadi
+   * and external files if necessary
+   *
+   * @param command Name of the part + version (NS:NAME[version])
+   * @param streamParser
+   * @param item Parent item
+   * @param checkExists Check whether the part already exists in Akonadi
+   * @param partName Returns name of the processed part
+   * @param partSizes Returns size of the part
+   * @param error Returns error string, if any error occurs
+   */
+  bool storeStreamedParts( const QByteArray &command, ImapStreamParser* streamParser,
+                           const PimItem &item, bool checkExists,
+                           QByteArray &partName, qint64 &partSize, QByteArray &error );
+} // namespace PartHelper
+
+} // namespace Server
+} // namespace Akonadi
 
 #endif
