@@ -29,7 +29,7 @@
 #include <QSqlRecord>
 #include <QSqlError>
 
-using namespace Akonadi;
+using namespace Akonadi::Server;
 
 static QString compareOperatorToString( Query::CompareOperator op )
 {
@@ -54,6 +54,8 @@ static QString compareOperatorToString( Query::CompareOperator op )
     return QLatin1String( " IN " );
   case Query::NotIn:
     return QLatin1String( " NOT IN " );
+  case Query::Like:
+    return QLatin1String( " LIKE " );
   }
   Q_ASSERT_X( false, "QueryBuilder::compareOperatorToString()", "Unknown compare operator." );
   return QString();
@@ -191,9 +193,6 @@ QString QueryBuilder::buildQuery()
     if ( mDistinct ) {
       statement += QLatin1String( "DISTINCT " );
     }
-    if ( mDatabaseType == DbType::Virtuoso && mLimit > 0 ) {
-      statement += QLatin1Literal( "TOP " ) + QString::number( mLimit ) + QLatin1Char( ' ' );
-    }
     Q_ASSERT_X( mColumns.count() > 0, "QueryBuilder::exec()", "No columns specified" );
     statement += mColumns.join( QLatin1String( ", " ) );
     statement += QLatin1String( " FROM " );
@@ -314,13 +313,24 @@ QString QueryBuilder::buildQuery()
     statement += orderStmts.join( QLatin1String( ", " ) );
   }
 
-  if ( mLimit > 0 && mDatabaseType != DbType::Virtuoso ) {
+  if ( mLimit > 0 ) {
     statement += QLatin1Literal( " LIMIT " ) + QString::number( mLimit );
   }
 
   return statement;
 }
 
+bool QueryBuilder::retryLastTransaction()
+{
+#ifndef QUERYBUILDER_UNITTEST
+  mQuery = DataStore::self()->retryLastTransaction();
+  return !mQuery.lastError().isValid();
+#else
+  return true;
+#endif
+}
+
+
 bool QueryBuilder::exec()
 {
   const QString statement = buildQuery();
@@ -343,7 +353,9 @@ bool QueryBuilder::exec()
     }
     //akDebug() << QString::fromLatin1( ":%1" ).arg( i ) <<  mBindValues[i];
   }
+
   bool ret;
+
   if ( StorageDebugger::instance()->isSQLDebuggingEnabled() ) {
     QTime t;
     t.start();
@@ -353,7 +365,6 @@ bool QueryBuilder::exec()
       ret = mQuery.exec();
     }
     StorageDebugger::instance()->queryExecuted( mQuery, t.elapsed() );
-
   } else {
     StorageDebugger::instance()->incSequence();
     if ( isBatch ) {
@@ -363,8 +374,42 @@ bool QueryBuilder::exec()
     }
   }
 
+  // Add the query to DataStore so that we can replay it in case transaction deadlocks.
+  // The method does nothing when this query is not executed within a transaction.
+  // We don't care whether the query was successful or not. In case of error, the caller
+  // will rollback the transaction anyway, and all cached queries will be removed.
+  DataStore::self()->addQueryToTransaction( mQuery, isBatch );
+
   if ( !ret ) {
-    akError() << "Error during executing query" << statement << ": " << mQuery.lastError().text();
+    // Handle transaction deadlocks and timeouts by attempting to replay the transaction.
+    if ( mDatabaseType == DbType::PostgreSQL ) {
+      const QString dbError = mQuery.lastError().databaseText();
+      if ( dbError.contains( QLatin1String( "40P01" /* deadlock_detected */ ) ) ) {
+        akDebug() << "QueryBuilder::exec(): database reported transaction deadlock, retrying transaction";
+        akDebug() << mQuery.lastError().text();
+        return retryLastTransaction();
+      }
+    } else if ( mDatabaseType == DbType::MySQL ) {
+      const int error = mQuery.lastError().number();
+      if ( error == 1213 /* ER_LOCK_DEADLOCK */ ) {
+        akDebug() << "QueryBuilder::exec(): database reported transaction deadlock, retrying transaction";
+        akDebug() << mQuery.lastError().text();
+        return retryLastTransaction();
+      } else if ( error == 1205 /* ER_LOCK_WAIT_TIMEOUT */ ) {
+        akDebug() << "QueryBuilder::exec(): database reported transaction timeout, retrying transaction";
+        akDebug() << mQuery.lastError().text();
+        return retryLastTransaction();
+      }
+    } else if ( mDatabaseType == DbType::Sqlite ) {
+      // We can't have a transaction deadlock in SQLite, because it does not support
+      // concurrent transactions and DataStore serializes them through a global lock.
+    }
+
+    akError() << "DATABASE ERROR:";
+    akError() << "  Error code:" << mQuery.lastError().number();
+    akError() << "  DB error: " << mQuery.lastError().databaseText();
+    akError() << "  Error text:" << mQuery.lastError().text();
+    akError() << "  Query:" << statement;
     return false;
   }
 #else
@@ -411,12 +456,12 @@ QString QueryBuilder::buildWhereCondition( const Query::Condition &cond )
     stmt += compareOperatorToString( cond.mCompareOp );
     if ( cond.mComparedColumn.isEmpty() ) {
       if ( cond.mComparedValue.isValid() ) {
-        if ( cond.mComparedValue.canConvert( QVariant::StringList ) ) {
+        if ( cond.mComparedValue.canConvert( QVariant::List ) ) {
           stmt += QLatin1String( "( " );
           QStringList entries;
-          Q_ASSERT_X( !cond.mComparedValue.toStringList().isEmpty(),
+          Q_ASSERT_X( !cond.mComparedValue.toList().isEmpty(),
                       "QueryBuilder::buildWhereCondition()", "No values given for IN condition." );
-          Q_FOREACH ( const QString &entry, cond.mComparedValue.toStringList() ) {
+          Q_FOREACH ( const QVariant &entry, cond.mComparedValue.toList() ) {
             entries << bindValue( entry );
           }
           stmt += entries.join( QLatin1String( ", " ) );
