@@ -35,6 +35,7 @@ class QueryBuilderTest;
 #endif
 
 namespace Akonadi {
+namespace Server {
 
 /**
   Helper class to construct arbitrary SQL queries.
@@ -243,6 +244,8 @@ class QueryBuilder
      */
     void sqliteAdaptUpdateJoin( Query::Condition &cond );
 
+    bool retryLastTransaction();
+
   private:
     QString mTable;
     DbType::Type mDatabaseType;
@@ -268,6 +271,7 @@ class QueryBuilder
 #endif
 };
 
-}
+} // namespace Server
+} // namespace Akonadi
 
 #endif
