@@ -28,8 +28,9 @@
 class QSqlQuery;
 
 namespace Akonadi {
+namespace Server {
 
-class StorageDebugger: public QObject
+class StorageDebugger : public QObject
 {
     Q_OBJECT
 
@@ -63,6 +64,7 @@ class StorageDebugger: public QObject
 
 };
 
-}
+} // namespace Server
+} // namespace Akonadi
 
 #endif // STORAGEDEBUGGER_H
